@@ -31,15 +31,10 @@ creating, and deleting of databases.
 #
 #-------------------------------------------------------------------------
 import os
-import sys
 import time
 import copy
-import shutil
 import subprocess
-if sys.version_info[0] < 3:
-    from urlparse import urlparse
-else:
-    from urllib.parse import urlparse
+from urllib.parse import urlparse
 
 #-------------------------------------------------------------------------
 #
@@ -49,7 +44,7 @@ else:
 import logging
 LOG = logging.getLogger(".DbManager")
 
-from gramps.gen.constfunc import win, UNITYPE, conv_to_unicode
+from gramps.gen.constfunc import win, conv_to_unicode
 if win():
     _RCS_FOUND = os.system("rcs -V >nul 2>nul") == 0
     if _RCS_FOUND and "TZ" not in os.environ:
@@ -74,6 +69,7 @@ from gi.repository import Pango
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
+from gramps.gen.const import URL_WIKISTRING
 from .user import User
 from .dialog import ErrorDialog, QuestionDialog, QuestionDialog2
 from gramps.gen.db import DbBsddb
@@ -105,7 +101,7 @@ FILE_COL  = 2
 DATE_COL  = 3
 DSORT_COL = 4
 OPEN_COL  = 5
-STOCK_COL = 6
+ICON_COL = 6
 
 RCS_BUTTON = { True : _('_Extract'), False : _('_Archive') }
 
@@ -116,9 +112,9 @@ class DbManager(CLIDbManager):
     """
     ICON_MAP = {
                 CLIDbManager.ICON_NONE : None,
-                CLIDbManager.ICON_RECOVERY : Gtk.STOCK_DIALOG_ERROR,
+                CLIDbManager.ICON_RECOVERY : 'dialog-error',
                 CLIDbManager.ICON_LOCK : 'gramps-lock',
-                CLIDbManager.ICON_OPEN : Gtk.STOCK_OPEN,
+                CLIDbManager.ICON_OPEN : 'document-open',
                }
 
     ERROR = ErrorDialog
@@ -129,13 +125,13 @@ class DbManager(CLIDbManager):
         the GTK widgets that are needed.
         """
         CLIDbManager.__init__(self, dbstate)
-        self.glade = Glade()
+        self.glade = Glade(toplevel='dbmanager')
         self.top = self.glade.toplevel
 
         if parent:
             self.top.set_transient_for(parent)
 
-        for attr in ['connect', 'cancel', 'new', 'remove', 'copy',
+        for attr in ['connect', 'cancel', 'new', 'remove',
                      'dblist', 'rename', 'repair', 'rcs', 'msg']:
             setattr(self, attr, self.glade.get_object(attr))
 
@@ -145,7 +141,6 @@ class DbManager(CLIDbManager):
         self.data_to_delete = None
 
         self.selection = self.dblist.get_selection()
-        self.dblist.set_rules_hint(True)
 
         self.__connect_signals()
         self.__build_interface()
@@ -165,7 +160,6 @@ class DbManager(CLIDbManager):
         self.remove.connect('clicked', self.__remove_db)
         self.new.connect('clicked', self.__new_db)
         self.rename.connect('clicked', self.__rename_db)
-        self.copy.connect('clicked', self.__copy_db)
         self.repair.connect('clicked', self.__repair_db)
         self.selection.connect('changed', self.__selection_changed)
         self.dblist.connect('button-press-event', self.__button_press)
@@ -222,7 +216,6 @@ class DbManager(CLIDbManager):
         if not node:
             self.connect.set_sensitive(False)
             self.rename.set_sensitive(False)
-            self.copy.set_sensitive(False)
             self.rcs.set_sensitive(False)
             self.repair.set_sensitive(False)
             self.remove.set_sensitive(False)
@@ -235,7 +228,7 @@ class DbManager(CLIDbManager):
         is_rev = len(path.get_indices()) > 1
         self.rcs.set_label(RCS_BUTTON[is_rev])
 
-        if store.get_value(node, STOCK_COL) == Gtk.STOCK_OPEN:
+        if store.get_value(node, ICON_COL) == 'document-open':
             self.connect.set_sensitive(False)
             if _RCS_FOUND:
                 self.rcs.set_sensitive(True)
@@ -246,7 +239,7 @@ class DbManager(CLIDbManager):
             else:
                 self.rcs.set_sensitive(False)
 
-        if store.get_value(node, STOCK_COL) == Gtk.STOCK_DIALOG_ERROR:
+        if store.get_value(node, ICON_COL) == 'dialog-error':
             path = conv_to_unicode(store.get_value(node, PATH_COL), 'utf8')
             backup = os.path.join(path, "person.gbkp")
             self.repair.set_sensitive(os.path.isfile(backup))
@@ -254,7 +247,6 @@ class DbManager(CLIDbManager):
             self.repair.set_sensitive(False)
             
         self.rename.set_sensitive(True)
-        self.copy.set_sensitive(True)
         self.remove.set_sensitive(True)
         self.new.set_sensitive(True)
 
@@ -293,7 +285,7 @@ class DbManager(CLIDbManager):
         # build the icon column
         render = Gtk.CellRendererPixbuf()
         #icon_column = Gtk.TreeViewColumn(_('Status'), render, 
-                                         #stock_id=STOCK_COL)
+                                         #icon_name=ICON_COL)
         icon_column = Gtk.TreeViewColumn(_('Status'), render)
         icon_column.set_cell_data_func(render, bug_fix)
         self.dblist.append_column(icon_column)
@@ -304,9 +296,6 @@ class DbManager(CLIDbManager):
         column.set_sort_column_id(DSORT_COL)
         self.dblist.append_column(column)
 
-        # set the rules hit
-        self.dblist.set_rules_hint(True)
-
     def __populate(self):
         """
         Builds the data and the display model.
@@ -357,7 +346,7 @@ class DbManager(CLIDbManager):
             if value == Gtk.ResponseType.OK:
                 store, node = self.selection.get_selected()
                 # don't open a locked file
-                if store.get_value(node, STOCK_COL) == 'gramps-lock':
+                if store.get_value(node, ICON_COL) == 'gramps-lock':
                     self.__ask_to_break_lock(store, node)
                     continue 
                 # don't open a version
@@ -405,7 +394,7 @@ class DbManager(CLIDbManager):
             dbpath = conv_to_unicode(store.get_value(node, PATH_COL), 'utf8')
             (tval, last) = time_val(dbpath)
             store.set_value(node, OPEN_COL, 0)
-            store.set_value(node, STOCK_COL, "")
+            store.set_value(node, ICON_COL, "")
             store.set_value(node, DATE_COL, last)
             store.set_value(node, DSORT_COL, tval)
         except IOError:
@@ -423,7 +412,6 @@ class DbManager(CLIDbManager):
         """
         self.connect.set_sensitive(False)
         self.rename.set_sensitive(False)
-        self.copy.set_sensitive(False)
         self.rcs.set_sensitive(False)
         self.repair.set_sensitive(False)
         self.remove.set_sensitive(False)
@@ -561,7 +549,7 @@ class DbManager(CLIDbManager):
                 _("Remove the '%s' Family Tree?") % self.data_to_delete[0],
                 _("Removing this Family Tree will permanently destroy the data."),
                 _("Remove Family Tree"),
-                self.__really_delete_db)
+                self.__really_delete_db, parent=self.top)
         else:
             rev = self.data_to_delete[0]
             parent = store[(path[0],)][0]
@@ -573,7 +561,7 @@ class DbManager(CLIDbManager):
                 _("Removing this version will prevent you from "
                   "extracting it in the future."),
                 _("Remove version"),
-                self.__really_delete_version)
+                self.__really_delete_version, parent=self.top)
 
     def __really_delete_db(self):
         """
@@ -645,26 +633,6 @@ class DbManager(CLIDbManager):
         self.name_renderer.set_property('editable', True)
         self.dblist.set_cursor(path, self.column, True)
 
-    def __copy_db(self, obj):
-        """
-        Copy the database through low-level file copies.
-        """
-        # First, get the selected tree:
-        store, node = self.selection.get_selected()
-        # New title:
-        date_string = time.strftime("%d %b %Y %H:%M:%S", time.gmtime())
-        title = _("%s (copy, %s)") % (store[node][NAME_COL], date_string)
-        # Create the row and directory, awaits user edit of title:
-        (new_dir, title) = self._create_new_db(title, create_db=False)
-        # Copy the files:
-        name_file = conv_to_unicode(store[node][FILE_COL], 'utf8')
-        old_dir = os.path.dirname(name_file)
-        for filename in os.listdir(old_dir):
-            if filename == "name.txt":
-                continue
-            old_file = os.path.abspath(os.path.join(old_dir, filename))
-            shutil.copy2(old_file, new_dir)
-
     def __repair_db(self, obj):
         """
         Start the repair process by calling the start_editing option on 
@@ -677,25 +645,37 @@ class DbManager(CLIDbManager):
         yes_no = QuestionDialog2(
             _("Repair Family Tree?"),
             _(
-"If you click <b>Proceed</b>, Gramps will attempt to recover your Family Tree"
-" from the last good backup. There are several ways this can cause unwanted"
-" effects, so <b>backup</b> the Family Tree first.\n"
-"The Family Tree you have selected is stored in %s.\n\n"
-"Before doing a repair, verify that the Family Tree can really no longer be "
-" opened, as the database back-end can recover from some errors automatically.\n\n"
-"<b>Details:</b> Repairing a Family Tree actually uses the last backup of"
-" the Family Tree, which Gramps stored on last use. If you have worked for"
-" several hours/days without closing Gramps, then all this information will"
-" be lost! If the repair fails, then the original Family Tree will be lost"
-" forever, hence a backup is needed. If the repair fails, or too much"
-" information is lost, you can fix the original Family Tree manually."
-" For details, see the webpage\n"
-"http://gramps-project.org/wiki/index.php?title=Recover_corrupted_family_tree\n"
-"Before doing a repair, try to open the Family Tree in the normal manner."
-" Several errors that trigger the repair button can be fixed automatically."
-" If this is the case, you can disable the repair button by removing the"
-" file <i>need_recover</i> in the Family Tree directory."
-) % dirname,
+              "If you click %(bold_start)sProceed%(bold_end)s, Gramps will "
+              "attempt to recover your Family Tree from the last good "
+              "backup. There are several ways this can cause unwanted "
+              "effects, so %(bold_start)sbackup%(bold_end)s the "
+              "Family Tree first.\nThe Family Tree you have selected "
+              "is stored in %(dirname)s.\n\n"
+              "Before doing a repair, verify that the Family Tree can "
+              "really no longer be opened, as the database back-end can "
+              "recover from some errors automatically.\n\n"
+              "%(bold_start)sDetails:%(bold_end)s Repairing a Family Tree "
+              "actually uses the last backup of the Family Tree, which "
+              "Gramps stored on last use. If you have worked for "
+              "several hours/days without closing Gramps, then all "
+              "this information will be lost! If the repair fails, then "
+              "the original Family Tree will be lost forever, hence "
+              "a backup is needed. If the repair fails, or too much "
+              "information is lost, you can fix the original "
+              "Family Tree manually. For details, see the webpage\n"
+              "%(gramps_wiki_recover_url)s\n"
+              "Before doing a repair, try to open the Family Tree "
+              "in the normal manner. Several errors that trigger the "
+              "repair button can be fixed automatically. "
+              "If this is the case, you can disable the repair button "
+              "by removing the file %(recover_file)s in the "
+              "Family Tree directory."
+             ) % { 'bold_start'   : '<b>' ,
+                   'bold_end'     : '</b>' ,
+                   'recover_file' : '<i>need_recover</i>' ,
+                   'gramps_wiki_recover_url' :
+                       URL_WIKISTRING + 'Recover_corrupted_family_tree',
+                   'dirname'      : dirname },
             _("Proceed, I have taken a backup"),
             _("Stop"))
         prompt = yes_no.run()
@@ -837,7 +817,7 @@ def find_revisions(name):
     get_next = False
     if os.path.isfile(name):
         for line in proc.stdout:
-            if sys.version_info[0] >= 3 and not isinstance(line, UNITYPE):
+            if not isinstance(line, str):
                 # we assume utf-8 ...
                 line = line.decode('utf-8')
             match = rev.match(line)
@@ -959,7 +939,7 @@ def bug_fix(column, renderer, model, iter_, data):
     None using the TreeModel set_value method.  Instead we set it to an empty
     string and convert it to None here.
     """
-    stock_id = model.get_value(iter_, STOCK_COL)
-    if stock_id == '':
-        stock_id = None
-    renderer.set_property('stock_id', stock_id)
+    icon_name = model.get_value(iter_, ICON_COL)
+    if icon_name == '':
+        icon_name = None
+    renderer.set_property('icon-name', icon_name)
