@@ -45,11 +45,11 @@ from gramps.gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
                                     TableStyle, TableCellStyle,
                                     FONT_SANS_SERIF, FONT_SERIF, 
                                     INDEX_TYPE_TOC, PARA_ALIGN_CENTER)
-from gramps.gen.proxy import PrivateProxyDb
 from gramps.gen.sort import Sort
-from gramps.gen.utils.location import get_main_location
+from gramps.gen.utils.location import get_location_list
 from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.lib import PlaceType
+from gramps.gen.errors import ReportError
 
 class PlaceReport(Report):
     """
@@ -70,7 +70,8 @@ class PlaceReport(Report):
         
         places          - List of places to report on.
         center          - Center of report, person or event
-        incpriv         - Whether to include private data
+        incl_private    - Whether to include private data
+        name_format     - Preferred format to display names
 
         """
 
@@ -78,33 +79,35 @@ class PlaceReport(Report):
 
         self._user = user
         menu = options.menu
+
+        stdoptions.run_private_data_option(self, menu)
+
         places = menu.get_option_by_name('places').get_value()
         self.center  = menu.get_option_by_name('center').get_value()
-        self.incpriv = menu.get_option_by_name('incpriv').get_value()
 
         self.set_locale(menu.get_option_by_name('trans').get_value())
 
-        name_format = menu.get_option_by_name("name_format").get_value()
-        if name_format != 0:
-            self._name_display.set_default_format(name_format)
+        stdoptions.run_name_format_option(self, menu)
         self._nd = self._name_display
 
-        if self.incpriv:
-            self.database = database
-        else:
-            self.database = PrivateProxyDb(database)
-
         filter_option = menu.get_option_by_name('filter')
         self.filter = filter_option.get_filter()
+
         self.sort = Sort(self.database)
 
+        self.place_handles = []
         if self.filter.get_name() != '':
             # Use the selected filter to provide a list of place handles
             plist = self.database.iter_place_handles()
             self.place_handles = self.filter.apply(self.database, plist)
-        else:
-            # Use the place handles selected without a filter
-            self.place_handles = self.__get_place_handles(places)
+
+        if places:
+            # Add places selected individually
+            self.place_handles += self.__get_place_handles(places)
+
+        if not self.place_handles:
+            raise ReportError(_('Place Report'),
+                _('Please select at least one place before running this.'))
 
         self.place_handles.sort(key=self.sort.by_place_title_key)
 
@@ -152,17 +155,13 @@ class PlaceReport(Report):
         This procedure writes out the details of a single place
         """
         place = self.database.get_place_from_handle(handle)
-        location = get_main_location(self.database, place)
 
-        place_details = [
-            self._("Gramps ID: %s ") % place.get_gramps_id(),
-            self._("Street: %s ") % location.get(PlaceType.STREET, ''),
-            self._("Parish: %s ") % location.get(PlaceType.PARISH, ''),
-            self._("Locality: %s ") % location.get(PlaceType.LOCALITY, ''),
-            self._("City: %s ") % location.get(PlaceType.CITY, ''),
-            self._("County: %s ") % location.get(PlaceType.COUNTY, ''),
-            self._("State: %s") % location.get(PlaceType.STATE, ''),
-            self._("Country: %s ") % location.get(PlaceType.COUNTRY, '')]
+        place_details = [self._("Gramps ID: %s ") % place.get_gramps_id()]
+        for level in get_location_list(self.database, place):
+            place_details.append("%(type)s: %(name)s " %
+                                 {'type': self._(level[1].xml_str()),
+                                  'name': level[0]})
+
         self.doc.start_paragraph("PLC-PlaceTitle")
         place_title = place_displayer.display(self.database, place)
         self.doc.write_text(("%(nbr)s. %(place)s") % 
@@ -202,7 +201,7 @@ class PlaceReport(Report):
 
         for evt_handle in event_handles:
             event = self.database.get_event_from_handle(evt_handle)
-            if event:
+            if event: # will be None if marked private
                 date = self._get_date(event.get_date_object())
                 descr = event.get_description()
                 event_type = self._(self._get_type(event.get_type()))
@@ -210,6 +209,8 @@ class PlaceReport(Report):
                 person_list = []
                 ref_handles = [x for x in
                                self.database.find_backlink_handles(evt_handle)]
+                if not ref_handles: # since the backlink may point to private
+                    continue        # data, ignore an event with no backlinks
                 for (ref_type, ref_handle) in ref_handles:
                     if ref_type == 'Person':
                         person_list.append(ref_handle)
@@ -392,12 +393,14 @@ class PlaceOptions(MenuReportOptions):
         opt.set_filters(filter_list)
         menu.add_option(category_name, "filter", opt)
 
-        stdoptions.add_name_format_option(menu, category_name)
-
         places = PlaceListOption(_("Select places individually"))
         places.set_help(_("List of places to report on"))
         menu.add_option(category_name, "places", places)
 
+        stdoptions.add_private_data_option(menu, category_name)
+
+        stdoptions.add_name_format_option(menu, category_name)
+
         center = EnumeratedListOption(_("Center on"), "Event")
         center.set_items([
                 ("Event",   _("Event")),
@@ -405,10 +408,6 @@ class PlaceOptions(MenuReportOptions):
         center.set_help(_("If report is event or person centered"))
         menu.add_option(category_name, "center", center)
 
-        incpriv = BooleanOption(_("Include private data"), True)
-        incpriv.set_help(_("Whether to include private data"))
-        menu.add_option(category_name, "incpriv", incpriv)
-
         stdoptions.add_localization_option(menu, category_name)
 
     def make_default_style(self, default_style):
